/*--------------------------スニペットに関して----------------------------/*
作成:source（ハル）
URL:https://source.sakuraweb.com/
作成日:2018年4月23日
更新日:2022年3月21日
バージョン:1.2.1
注意事項:使用前に必ず同梱の説明書.txtをお読み下さい。
-------------------------------------------------------------------------*/
document.addEventListener("DOMContentLoaded", () => {
    "use strict";
    /*--------------------------ここからユーザー設定--------------------------*/
    //対象のクラス名
    const class_name = "dtimer";
    //対象クラスの領域削除判定(true:false)
    const area_delete = true;
    //再表示時CSS display値※対象クラスの領域削除判定がtrueの場合のみ影響有
    const before_disp = "block";
    //点滅開始終了前時間(設定秒前)
    const flash_time = 600;
    //点滅間隔(設定秒間隔)
    const interval_time = 1;
    /*--------------------------ここまでユーザー設定--------------------------*/
    //スタイルシートをhead内に挿入
    const css = document.createElement("style");
    const keyframes = "\n@keyframes flash { \n" +
                    "  0%{visibility: visible;}\n" +
                    "  50%{visibility: hidden;}\n" +
                    "}\n";
    const rules = document.createTextNode(keyframes);
    css.appendChild(rules);
    document.getElementsByTagName("head")[0].appendChild(css);
    //時分秒を秒変換
    const secondConv = (data) => {
        const h = data.split(":").length > 0 ? (!Number.isNaN(Number(data.split(":")[0])) ? Number(data.split(":")[0]) : 0) : 0;
        const m = data.split(":").length > 1 ? (!Number.isNaN(Number(data.split(":")[1])) ? Number(data.split(":")[1]) : 0) : 0;
        const s = data.split(":").length > 2 ? (!Number.isNaN(Number(data.split(":")[2])) ? Number(data.split(":")[2]) : 0) : 0;
        return (h * 60 + m) * 60 + s;
    };
    //月日を分割
    const dateSplit = (data, select) => {
        if(data.split("/").length = 2){
            if(select === "m"){
                return !Number.isNaN(Number(data.split("/")[0])) ? Number(data.split("/")[0]) : 1;
            }else{
                return !Number.isNaN(Number(data.split("/")[1])) ? Number(data.split("/")[1]) : 1;
            }
        }else{
            return 1;
        }
    }
    //ノード単体に対する設定を行う
    function display(elem, nmonth, nday, nweek, ntime){
        //ノードに設定されている値を取得する
        const data   = elem.dataset;
        const smonth = data.sdate !== undefined ? dateSplit(data.sdate, "m") : 1;
        const emonth = data.edate !== undefined ? dateSplit(data.edate, "m") : 12;
        const sday   = data.sdate !== undefined ? dateSplit(data.sdate, "d") : 1;
        const eday   = data.edate !== undefined ? dateSplit(data.edate, "d") : 31;
        const dday   = data.dday  !== undefined ? data.dday.split(",") : false;
        const week   = data.week  !== undefined ? data.week.split(",") : false;
        const stime  = data.stime !== undefined ? secondConv(data.stime) : 0;
        const etime  = data.etime !== undefined ? secondConv(data.etime) : 86400;
        const flash  = data.flash||false;
        const color  = data.color||false;
        const tag    = elem.tagName;
        //スタイル変更用フラグ
        let show_flg  = false;
        let flash_flg = false;
        let color_flg = false;
        //表示判定
        if((!week || week.includes(nweek)) && (!dday || dday.includes(nday + "")) &&
        (smonth <= nmonth && nmonth <= emonth) && (sday <= nday && nday <= eday) &&
        (stime <= ntime && ntime <= etime)){
            show_flg = true;
            //点滅開始終了前時間判定
            if(etime - ntime < flash_time){
                flash_flg = flash;
                color_flg = color && (/(p|a|span)/i).test(tag);
            }
        }
        //スタイル変更
        const add_style = "flash " + interval_time + "s steps(1) infinite";
        if(area_delete){
            elem.style.display = show_flg ? before_disp : "none";
        }else{
            elem.style.visibility = show_flg ? "visible" : "hidden";
        }
        elem.style.animation = flash_flg ? add_style : "none";
        elem.style.color = color_flg ? color : null;
    }
    //指定したノードリストに対する点灯・点滅設定を行う
    const elem_all = document.querySelectorAll("." + class_name);
    const elems = Array.prototype.slice.call(elem_all,0);
    (function displayAll(){
        const today = new Date();
        const nmonth = today.getMonth() + 1
        const nday   = today.getDate()
        const ntime = secondConv(today.getHours() + ":" + today.getMinutes() + ":" + today.getSeconds());
        const nweek = ["日", "月", "火", "水", "木", "金", "土"][today.getDay()];
        elems.forEach((elem) => display(elem, nmonth, nday, nweek, ntime));
        setTimeout(displayAll, 1000);
    }());
});
